@@ -101,7 +101,7 @@ def play_sound(args,printer):
 ## HELPERS
 
 def should_ignore(message):
-    ignore_messages = [ "has joined #" ]
+    ignore_messages = [ "has joined #", "is now known as" ]
     for msg_to_ignore in ignore_messages:
         if message.find(msg_to_ignore):
             return True
